/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { haveValue } from '../../support/cypress.util';

export class PostfachE2EComponent {
  private readonly headline: string = 'headline';
  private readonly signaturText: string = 'signature-textarea';
  private readonly saveSignaturButton: string = 'save-button';

  public getHeadline(): any {
    return cy.getTestElement(this.headline);
  }

  public getSignaturText(): any {
    return cy.getTestElement(this.signaturText);
  }

  public setSignatur(signatur: string): void {
    this.clearSignatur();
    this.getSignaturText().type(signatur);
  }

  public clearSignatur(): void {
    this.getSignaturText().type('{selectAll}{del}');
  }

  public getSaveButton(): Cypress.Chainable<Element> {
    return cy.getTestElement(this.saveSignaturButton);
  }

  public saveSignatur(): void {
    this.getSaveButton().click();
  }

  public signatureIs(compare: string): void {
    haveValue(this.getSignaturText(), compare);
  }

  public scrollbarIsPresent(): void {
    this.getSignaturText().then((textarea) => {
      const scrollHeight = textarea[0].scrollHeight;
      const clientHeight = textarea[0].clientHeight;

      expect(scrollHeight).to.be.greaterThan(clientHeight);
    });
  }
}
