import { E2EOrganisationsEinheitHelper } from 'apps/admin-e2e/src/helper/organisations-einheit/organisations-einheit.helper';
import { E2EOrganisationsEinheitVerifier } from 'apps/admin-e2e/src/helper/organisations-einheit/organisations-einheit.verifier';
import { OrganisationsEinheitPage } from 'apps/admin-e2e/src/page-objects/organisations-einheit.po';
import { ZustaendigeStelleDialogE2EComponent } from '../../../components/zustaendige-stelle/zustaendige-stelle-dialog.e2e.component';
import { exist } from '../../../support/cypress.util';
import { loginAsAriane } from '../../../support/user-util';

describe('Organisationseinheit', () => {
  const organisationsEinheitPage: OrganisationsEinheitPage = new OrganisationsEinheitPage();

  const organisationsEinheitHelper: E2EOrganisationsEinheitHelper = new E2EOrganisationsEinheitHelper();
  const organisationsEinheitVerifier: E2EOrganisationsEinheitVerifier = new E2EOrganisationsEinheitVerifier();

  const zustaendigeStelleSearchComponent: ZustaendigeStelleDialogE2EComponent = new ZustaendigeStelleDialogE2EComponent();

  const organisationsEinheit: string = 'Wasserwerk - Hamburg Wasser - Hamburger Stadtentwässerung';

  before(() => {
    loginAsAriane();
  });

  describe('hinzufügen', () => {
    it('should show search dialog on add button click', () => {
      organisationsEinheitHelper.openOrganisationsEinheitPage();

      organisationsEinheitPage.getAddButton().click();

      exist(zustaendigeStelleSearchComponent.getZustaendigeStelleForm());
    });

    it('should find at least one organisationseinheit on search', () => {
      zustaendigeStelleSearchComponent.enterSearchTerm(organisationsEinheit);

      zustaendigeStelleSearchComponent.expectNumberOfEntriesToBeGreaterThan(1);
    });

    it('should show organisationseinheit in list', () => {
      organisationsEinheitHelper.addOrganisationsEinheit(organisationsEinheit);

      organisationsEinheitVerifier.verifyOrganisationsEinheitInList(organisationsEinheit);
    });
  });

  describe('löschen', () => {
    it('should not show entry in list', () => {
      organisationsEinheitHelper.openOrganisationsEinheitPage();

      organisationsEinheitHelper.deleteOrganisationsEinheit(organisationsEinheit);

      organisationsEinheitVerifier.verifyOrganisationsEinheitNotInList(organisationsEinheit);
    });
  });
});
