/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
export class VorgangMoreMenuE2EComponent {
  private readonly rootLocator: string = 'more-menu';
  private readonly buttonLocator: string = 'more-menu-button';

  private readonly exportierenItem: VorgangMoreMenuExportierenItemE2EComponent = new VorgangMoreMenuExportierenItemE2EComponent();
  private readonly vorpruefenItem: VorgangMoreMenuVorpruefenItemE2EComponent = new VorgangMoreMenuVorpruefenItemE2EComponent();
  private readonly archivierenItem: VorgangMoreMenuArchivierenItemE2EComponent = new VorgangMoreMenuArchivierenItemE2EComponent();

  public getRoot() {
    return cy.getTestElementWithOid(this.rootLocator);
  }

  //TODO in die Subnavigation verschieben
  public getButton() {
    return this.getRoot().getTestElementWithOid(this.buttonLocator);
  }

  public openMenu(): void {
    this.getButton().click();
  }

  public getExportierenItem(): VorgangMoreMenuExportierenItemE2EComponent {
    return this.exportierenItem;
  }

  public getVorpruefenItem(): VorgangMoreMenuVorpruefenItemE2EComponent {
    return this.vorpruefenItem;
  }

  public getArchivierenItem(): VorgangMoreMenuArchivierenItemE2EComponent {
    return this.archivierenItem;
  }
}

export class VorgangMoreMenuExportierenItemE2EComponent {
  private readonly root: string = 'vorgang-exportieren-button';
  private readonly button: string = 'export-vorgang';

  public getRoot(): Cypress.Chainable<JQuery<HTMLElement>> {
    return cy.getTestElementWithOid(this.root);
  }

  public getButton(): Cypress.Chainable<JQuery<HTMLElement>> {
    return this.getRoot().getTestElementWithOid(this.button);
  }
}

export class VorgangMoreMenuVorpruefenItemE2EComponent {
  private readonly root: string = 'vorgang-process-vorgang-button';
  private readonly button: string = 'process-vorgang';

  public getRoot(): Cypress.Chainable<JQuery<HTMLElement>> {
    return cy.getTestElementWithOid(this.root);
  }

  public getButton(): Cypress.Chainable<JQuery<HTMLElement>> {
    return this.getRoot().getTestElementWithOid(this.button);
  }
}

export class VorgangMoreMenuArchivierenItemE2EComponent {
  private readonly root: string = 'vorgang-archive-button';
  private readonly button: string = 'archive-vorgang';
  private readonly archivierenConfirm: string = 'archive-confirmation-button';
  private readonly archivierenCancel: string = 'archive-cancel-button';

  public getRoot(): Cypress.Chainable<JQuery<HTMLElement>> {
    return cy.getTestElementWithOid(this.root);
  }

  public getButton(): Cypress.Chainable<JQuery<HTMLElement>> {
    return this.getRoot().getTestElementWithOid(this.button);
  }

  public clickArchivieren(): void {
    this.getButton().click({ force: true });
  }

  public getArchivierenConfirm(): Cypress.Chainable<JQuery<HTMLElement>> {
    return cy.getTestElement(this.archivierenConfirm);
  }

  public getArchivierenCancel(): Cypress.Chainable<JQuery<HTMLElement>> {
    return cy.getTestElement(this.archivierenCancel);
  }

  public confirmArchivieren(): void {
    this.getArchivierenConfirm().click();
  }

  public cancelArchivieren(): void {
    this.getArchivierenCancel().click();
  }
}
