import { registerLocaleData } from '@angular/common';
import localeDe from '@angular/common/locales/de';
import localeDeExtra from '@angular/common/locales/extra/de';
import { VorgangFormularButtonsE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-formular-buttons.e2e.components';
import { ForwardingDialogE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-forwarding-dialog.e2e.component';
import { VorgangListE2EComponent } from '../../../components/vorgang/vorgang-list.e2e.component';
import { E2EVorgangNavigator } from '../../../helper/vorgang/vorgang.navigator';
import { E2EVorgangVerifier } from '../../../helper/vorgang/vorgang.verifier';
import { VorgangE2E } from '../../../model/vorgang';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { VorgangPage } from '../../../page-objects/vorgang.po';
import { dropCollections } from '../../../support/cypress-helper';
import { beAriaDisabled, contains, exist, notBeAriaDisabled, notExist } from '../../../support/cypress.util';
import { loginAsPeter, loginAsSabine } from '../../../support/user-util';
import { createVorgang, initVorgaenge } from '../../../support/vorgang-util';

registerLocaleData(localeDe, 'de', localeDeExtra);

describe('Vorgang weiterleiten', () => {
  const vorgangNavigator: E2EVorgangNavigator = new E2EVorgangNavigator();
  const vorgangVerifier: E2EVorgangVerifier = new E2EVorgangVerifier();

  const mainPage: MainPage = new MainPage();
  const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();

  const organisationsEinheitName = 'Landeshauptstadt Kiel - Pries-Friedrichsort Stadtteilamt';
  const organisationsEinheitAddress = 'An der Schanze 45, 24159 Kiel';

  const vorgangPage: VorgangPage = new VorgangPage();
  const forwardingDialog: ForwardingDialogE2EComponent = vorgangPage.getForwardingDialogContainer();
  const vorgangFormularButtons: VorgangFormularButtonsE2EComponent = vorgangPage.getFormularButtons();

  const vorgangWeiterleiten: VorgangE2E = { ...createVorgang(), name: 'Weiterleitung' };

  after(() => {
    dropCollections();
  });

  describe('For Sabine', () => {
    before(() => {
      initVorgaenge([vorgangWeiterleiten]);

      loginAsSabine();

      waitForSpinnerToDisappear();
      exist(vorgangList.getRoot());
    });

    it('should display Weiterleiten button in Status Neu', () => {
      vorgangList.getListItem(vorgangWeiterleiten.name).getRoot().click();
      waitForSpinnerToDisappear();

      vorgangVerifier.verifyForwardingButtonExists();
    });

    it('should open forwarding dialog on forward button click', () => {
      vorgangFormularButtons.getForwardButton().click();

      exist(forwardingDialog.getRoot());
    });

    it('should have organisations einheit search', () => {
      exist(forwardingDialog.getOrganisationsEinheitSearch());
    });

    it('should have disabled forwarding button', () => {
      beAriaDisabled(forwardingDialog.getForwardingButton());
    });

    it('should close dialog on escape', () => {
      forwardingDialog.getRoot().type('{esc}');

      notExist(forwardingDialog.getRoot());
    });

    it('should close dialog on abbrechen button', () => {
      vorgangFormularButtons.getForwardButton().click();
      forwardingDialog.getCancelButton().click();

      notExist(forwardingDialog.getRoot());
    });

    it('should close dialog on x icon', () => {
      vorgangFormularButtons.getForwardButton().click();
      forwardingDialog.getCancelIconButton().click();

      notExist(forwardingDialog.getRoot());
    });

    it('should show selected search item on search select', () => {
      vorgangFormularButtons.getForwardButton().click();
      forwardingDialog.search(organisationsEinheitName);
      forwardingDialog.clickSearchEntry(0);

      exist(forwardingDialog.getSelectedSearchItem());
      contains(forwardingDialog.getSelectedSearchItem(), organisationsEinheitName);
      contains(forwardingDialog.getSelectedSearchItem(), organisationsEinheitAddress);
    });

    it('should not show zufi search on search select', () => {
      notExist(forwardingDialog.getOrganisationsEinheitSearch());
    });

    it('should not disable forwarding button on search select', () => {
      notBeAriaDisabled(forwardingDialog.getForwardingButton());
    });

    it('should clear selected search item on change button click', () => {
      forwardingDialog.getChangeButton().click();

      notExist(forwardingDialog.getSelectedSearchItem());
      exist(forwardingDialog.getOrganisationsEinheitSearch());
      beAriaDisabled(forwardingDialog.getForwardingButton());
    });

    it('should not display Weiterleiten button in status Angenommen', () => {
      forwardingDialog.getCancelButton().click();
      vorgangFormularButtons.getAnnehmenButton().click();
      waitForSpinnerToDisappear();

      vorgangVerifier.verifyNoForwardingButtonExists();
    });

    it('should not display Weiterleiten button in status In Bearbeitung', () => {
      vorgangFormularButtons.getBearbeitenButton().click();
      waitForSpinnerToDisappear();

      vorgangVerifier.verifyNoForwardingButtonExists();
    });
  });

  describe('For Peter', () => {
    before(() => {
      initVorgaenge([vorgangWeiterleiten]);

      loginAsPeter();

      waitForSpinnerToDisappear();
      exist(vorgangList.getRoot());
    });

    it('should display Weiterleiten button in Status In Neu', () => {
      vorgangNavigator.openVorgangDetailByName(vorgangWeiterleiten.name);

      vorgangVerifier.verifyForwardingButtonExists();
    });
  });
});
