{{/* vim: set filetype=mustache: */}}

{{/* error check 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec) */}}
{{/* Namespace */}}
{{- define "app.namespace" -}}
{{- if gt (len (.Release.Namespace)) 63 -}}
{{- fail (printf ".Release.Namespace %s ist zu lang (max. 63 Zeichen)" .Release.Namespace) -}}
{{- end -}}
{{ printf "%s" .Release.Namespace }}
{{- end -}}

{{/* Chart: Name + Version */}}
{{- define "app.chart" -}}
{{- if gt (len (printf "%s-%s" .Chart.Name .Chart.Version)) 63 -}}
{{- fail (printf ".Chart.Name-.Chart.Version %s-%s ist zu lang (max. 63 Zeichen)" .Chart.Name .Chart.Version) -}}
{{- end -}}
{{ printf "%s-%s" .Chart.Name .Chart.Version }}
{{- end -}}

{{/* Managed-by -> On Helm, this value is always Helm */}}
{{- define "app.managedBy" -}}
{{- if gt (len (.Release.Service)) 63 -}}
{{- fail (printf ".Release.Service %s ist zu lang (max. 63 Zeichen)" .Release.Service) -}}
{{- end -}}
{{ printf "%s" .Release.Service }}
{{- end -}}

{{/* Default Labels: Helm recommended best-practice labels https://helm.sh/docs/chart_best_practices/labels/ */}}
{{- define "app.defaultLabels" }}
app.kubernetes.io/instance: info-client
app.kubernetes.io/managed-by: {{ include "app.managedBy" . }}
app.kubernetes.io/part-of: ozgcloud
app.kubernetes.io/version: {{ .Chart.Version }}
helm.sh/chart: {{ include "app.chart" . }}
{{- include "app.matchLabels" . }}
{{- end -}}

{{- define "app.matchLabels" }}
app.kubernetes.io/name: {{ .Release.Name }}
app.kubernetes.io/namespace: {{ include "app.namespace" . }}
{{- end -}}

{{- define "app.getBaseDomain" -}}
{{- required "baseDomain muss angegeben sein" .Values.baseDomain }}
{{- end -}}

{{- define "app.getCustomList" -}}
{{- with (.Values.env).customList -}}
{{- if kindIs "map" . -}}
{{ include "app.dictToList" . }}
{{- else if kindIs "slice" . -}}
{{ . | toYaml }}
{{- end -}}
{{- end -}}
{{- end -}}

{{- define "app.dictToList" -}}
{{- $customList := list -}}
{{- range $key, $value := . -}}
{{- $customList = append $customList (dict "name" $key "value" $value) }}
{{- end -}}
{{- $customList | toYaml -}}
{{- end -}}

{{- define "app.getIngressTlsSecretName" -}}
{{- if (.Values.ingress).tlsSecretName -}}
{{ (.Values.ingress).tlsSecretName }}
{{- else -}}
{{ printf "%s-tls" .Release.Name }}
{{- end -}}
{{- end -}}

{{- define "app.getImageName" -}}
{{- required "image.name muss angegeben sein" .Values.image.name }}
{{- end -}}

{{- define "app.getBarrierefreiheitUrl" -}}
{{- if .Values.keycloakTheme.barrierefreiheitUrl -}}
{{ .Values.keycloakTheme.barrierefreiheitUrl }}
{{- else -}}
{{ printf "https://%s/barrierefreiheit" .Values.baseDomain }}
{{- end -}}
{{- end -}}

{{- define "app.getDatenschutzUrl" -}}
{{- if .Values.keycloakTheme.datenschutzUrl -}}
{{ .Values.keycloakTheme.datenschutzUrl }}
{{- else -}}
{{ printf "https://%s/datenschutz" .Values.baseDomain }}
{{- end -}}
{{- end -}}

{{- define "app.getImpressumUrl" -}}
{{- if .Values.keycloakTheme.impressumUrl -}}
{{ .Values.keycloakTheme.impressumUrl }}
{{- else -}}
{{ printf "https://%s/impressum" .Values.baseDomain }}
{{- end -}}
{{- end -}}