import { AdminOrganisationsEinheit } from '@admin-client/organisations-einheit-shared';
import { inject, Injectable } from '@angular/core';
import KcAdminClient from '@keycloak/keycloak-admin-client';
import GroupRepresentation from '@keycloak/keycloak-admin-client/lib/defs/groupRepresentation';
import { from, map, Observable } from 'rxjs';

@Injectable({
  providedIn: 'root',
})
export class AdminOrganisationsEinheitRepository {
  private readonly kcAdminClient = inject(KcAdminClient);

  public getList(): Observable<AdminOrganisationsEinheit[]> {
    return this.getGroupsInKeycloak().pipe(
      map((groupReps: GroupRepresentation[]): AdminOrganisationsEinheit[] => this.mapToOrganisationsEinheiten(groupReps)),
    );
  }

  private getGroupsInKeycloak(): Observable<GroupRepresentation[]> {
    return from(this.kcAdminClient.groups.find({ briefRepresentation: false })).pipe(
      map((groups: GroupRepresentation[]): GroupRepresentation[] => groups || []),
    );
  }

  public create(organisationseinheit: AdminOrganisationsEinheit): Observable<AdminOrganisationsEinheit> {
    return this.createGroupInKeycloak(organisationseinheit).pipe(map(this.mapToOrganisationsEinheit));
  }

  private createGroupInKeycloak(organisationseinheit: AdminOrganisationsEinheit): Observable<GroupRepresentation> {
    return from(this.kcAdminClient.groups.create(organisationseinheit));
  }

  private mapToOrganisationsEinheiten(groupRepresentations: GroupRepresentation[]): AdminOrganisationsEinheit[] {
    return groupRepresentations.map(
      (group: GroupRepresentation): AdminOrganisationsEinheit => this.mapToOrganisationsEinheit(group),
    );
  }

  private mapToOrganisationsEinheit(group: GroupRepresentation): AdminOrganisationsEinheit {
    return {
      id: group.id,
      name: group.name,
      attributes: group.attributes,
    };
  }

  public delete(organisationseinheitId: string): Observable<void> {
    return from(this.kcAdminClient.groups.del({ id: organisationseinheitId }));
  }
}
