import { BescheidLinkRel, BescheidSendBy } from '@alfa-client/bescheid-shared';
import { HasLinkPipe } from '@alfa-client/tech-shared';
import {
  existsAsHtmlElement,
  getElementComponentFromFixtureByCss,
  notExistsAsHtmlElement,
  triggerEvent,
} from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { FormBuilder, ReactiveFormsModule } from '@angular/forms';
import { RadioButtonCardComponent, SaveIconComponent, SendIconComponent } from '@ods/system';
import { MockComponent } from 'ng-mocks';
import { createBescheidResource } from '../../../../../../../bescheid-shared/src/test/bescheid';
import { getDataTestIdOf } from '../../../../../../../tech-shared/test/data-test';
import { BescheidFormService } from '../../../bescheid.formservice';
import { BescheidWizardBescheidVersendenFormComponent } from './bescheid-wizard-bescheid-versenden-form.component';

describe('BescheidWizardBescheidVersendenFormComponent', () => {
  let component: BescheidWizardBescheidVersendenFormComponent;
  let fixture: ComponentFixture<BescheidWizardBescheidVersendenFormComponent>;

  const sendBescheidMessageTestId: string = getDataTestIdOf('send-to-antragsteller-button');
  const saveBeschedTestId: string = getDataTestIdOf('save-button');

  let formService: BescheidFormService;

  beforeEach(() => {
    formService = new BescheidFormService(new FormBuilder(), null);
  });

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        BescheidWizardBescheidVersendenFormComponent,
        MockComponent(RadioButtonCardComponent),
        MockComponent(SendIconComponent),
        MockComponent(SaveIconComponent),
        HasLinkPipe,
        ReactiveFormsModule,
      ],
      providers: [{ provide: BescheidFormService, useValue: formService }],
    }).compileComponents();

    fixture = TestBed.createComponent(BescheidWizardBescheidVersendenFormComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  describe('component', () => {
    it('should create', () => {
      expect(component).toBeTruthy();
    });

    describe('changeSendBy', () => {
      it('should emit', () => {
        component.sendBy.emit = jest.fn();

        component.changeSendBy(BescheidSendBy.NACHRICHT);

        expect(component.sendBy.emit).toHaveBeenCalledWith(BescheidSendBy.NACHRICHT);
      });
    });
  });

  describe('template', () => {
    describe('als neue nachricht radio button', () => {
      it('should exists', () => {
        component.bescheidResource = createBescheidResource([BescheidLinkRel.BESCHEIDEN_UND_SENDEN]);

        fixture.detectChanges();

        existsAsHtmlElement(fixture, sendBescheidMessageTestId);
      });

      it('should NOT exists', () => {
        component.bescheidResource = createBescheidResource();

        fixture.detectChanges();

        notExistsAsHtmlElement(fixture, sendBescheidMessageTestId);
      });

      it('should have inputs', () => {
        component.bescheidResource = createBescheidResource([BescheidLinkRel.BESCHEIDEN_UND_SENDEN]);

        fixture.detectChanges();
        const radioButton: RadioButtonCardComponent = getElementComponentFromFixtureByCss<RadioButtonCardComponent>(
          fixture,
          sendBescheidMessageTestId,
        );

        expect(radioButton.value).toEqual(BescheidSendBy.NACHRICHT);
        expect(radioButton.name).toEqual(BescheidFormService.FIELD_SEND_BY);
        expect(radioButton.fullWidthText).toEqual(true);
      });

      describe('output', () => {
        describe('change', () => {
          it('should call handler', () => {
            component.bescheidResource = createBescheidResource([BescheidLinkRel.BESCHEIDEN_UND_SENDEN]);
            component.changeSendBy = jest.fn();
            fixture.detectChanges();

            triggerEvent({ fixture, elementSelector: sendBescheidMessageTestId, name: 'change', data: BescheidSendBy.NACHRICHT });

            expect(component.changeSendBy).toHaveBeenCalledWith(BescheidSendBy.NACHRICHT);
          });
        });
      });
    });

    describe('nur speichern radio button', () => {
      it('should exists', () => {
        component.bescheidResource = createBescheidResource([BescheidLinkRel.BESCHEIDEN_UND_SENDEN, BescheidLinkRel.BESCHEIDEN]);

        fixture.detectChanges();

        existsAsHtmlElement(fixture, saveBeschedTestId);
      });

      it('should NOT exists if on missing bescheiden und send link', () => {
        component.bescheidResource = createBescheidResource([BescheidLinkRel.BESCHEIDEN]);

        fixture.detectChanges();

        notExistsAsHtmlElement(fixture, saveBeschedTestId);
      });

      it('should NOT exists if on missing bescheiden link', () => {
        component.bescheidResource = createBescheidResource([BescheidLinkRel.BESCHEIDEN_UND_SENDEN]);

        fixture.detectChanges();

        notExistsAsHtmlElement(fixture, saveBeschedTestId);
      });

      it('should NOT exists if on missinglinks', () => {
        component.bescheidResource = createBescheidResource();

        fixture.detectChanges();

        notExistsAsHtmlElement(fixture, saveBeschedTestId);
      });

      it('should have inputs', () => {
        component.bescheidResource = createBescheidResource([BescheidLinkRel.BESCHEIDEN_UND_SENDEN, BescheidLinkRel.BESCHEIDEN]);

        fixture.detectChanges();
        const radioButton: RadioButtonCardComponent = getElementComponentFromFixtureByCss<RadioButtonCardComponent>(
          fixture,
          saveBeschedTestId,
        );

        expect(radioButton.value).toEqual(BescheidSendBy.MANUAL);
        expect(radioButton.name).toEqual(BescheidFormService.FIELD_SEND_BY);
        expect(radioButton.fullWidthText).toEqual(true);
      });

      describe('output', () => {
        describe('change', () => {
          it('should call handler', () => {
            component.bescheidResource = createBescheidResource([
              BescheidLinkRel.BESCHEIDEN_UND_SENDEN,
              BescheidLinkRel.BESCHEIDEN,
            ]);
            component.changeSendBy = jest.fn();
            fixture.detectChanges();

            triggerEvent({ fixture, elementSelector: saveBeschedTestId, name: 'change', data: BescheidSendBy.MANUAL });

            expect(component.changeSendBy).toHaveBeenCalledWith(BescheidSendBy.MANUAL);
          });
        });
      });
    });
  });
});
