/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidDocument, BescheidLinkRel, BescheidResource } from '@alfa-client/bescheid-shared';
import { tapOnCommandSuccessfullyDone } from '@alfa-client/command-shared';
import { isNotNil, StateResource } from '@alfa-client/tech-shared';
import { Component, EventEmitter, inject, Input, Output } from '@angular/core';
import { Resource } from '@ngxp/rest';
import { isNil } from 'lodash-es';
import { Observable } from 'rxjs';
import { BescheidFormService } from '../../../bescheid.formservice';

@Component({
  selector: 'alfa-bescheid-wizard-dokumente-hochladen-form',
  templateUrl: './bescheid-wizard-dokumente-hochladen-form.component.html',
})
export class BescheidWizardDokumenteHochladenFormComponent {
  @Input() set bescheidDocument(value: BescheidDocument) {
    this._bescheidDocument = value;
    if (isNotNil(value.resource)) {
      this.bescheidDocumentMissing.emit(false);
    }
  }

  @Input() bescheidResource: BescheidResource;

  @Output() weiterClickEmitter: EventEmitter<void> = new EventEmitter<void>();
  @Output() bescheidDocumentMissing: EventEmitter<boolean> = new EventEmitter<boolean>();

  private readonly formService = inject(BescheidFormService);

  public submitStateResource$: Observable<StateResource<Resource>>;

  private _bescheidDocument: BescheidDocument;

  protected readonly BescheidLinkRel = BescheidLinkRel;

  public gotoNextStep(): void {
    if (isNil(this._bescheidDocument.resource)) {
      this.bescheidDocumentMissing.emit(true);
    } else {
      this.submitStateResource$ = this.formService
        .submit()
        .pipe(tapOnCommandSuccessfullyDone(() => this.weiterClickEmitter.emit()));
    }
  }
}
