import { expect } from '@jest/globals';
import {
  _horizontalClasses,
  _verticalClasses,
  BinaryFileListOrientation,
  BinaryFileListOrientationDirective,
} from './binary-file-list-orientation.directive';

describe('BinaryFileListOrientationDirective', () => {
  let directive: BinaryFileListOrientationDirective;
  let elementRef: any = {};

  beforeEach(() => {
    elementRef = {
      nativeElement: {
        classList: {
          add: jest.fn(),
        },
      },
    };
    directive = new BinaryFileListOrientationDirective(elementRef);
  });

  describe('set binaryFileListOrientation', () => {
    beforeEach(() => {
      directive._evaluateClasses = jest.fn().mockReturnValue([]);
    });

    it('should evaluate classes', () => {
      directive.binaryFileListOrientation = BinaryFileListOrientation.HORIZONTAL;

      expect(directive._evaluateClasses).toHaveBeenCalledWith(BinaryFileListOrientation.HORIZONTAL);
    });

    it('should add classes', () => {
      const classes: string[] = ['test'];
      directive._evaluateClasses = jest.fn().mockReturnValue(classes);

      directive.binaryFileListOrientation = BinaryFileListOrientation.HORIZONTAL;

      expect(elementRef.nativeElement.classList.add).toHaveBeenCalledWith('test');
    });
  });

  describe('_evaluateClasses', () => {
    it('should return horizontal classes', () => {
      const classes: string[] = directive._evaluateClasses(BinaryFileListOrientation.HORIZONTAL);

      expect(classes).toEqual(_horizontalClasses);
    });

    it('should return vertical classes', () => {
      const classes: string[] = directive._evaluateClasses(BinaryFileListOrientation.VERTICAL);

      expect(classes).toEqual(_verticalClasses);
    });

    it('should return horizontal classes by default', () => {
      const classes: string[] = directive._evaluateClasses(null);

      expect(classes).toEqual(_horizontalClasses);
    });
  });
});
