/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { CollaborationListLinkRel, CollaborationListResource } from '@alfa-client/collaboration-shared';
import { HasLinkPipe, createStateResource } from '@alfa-client/tech-shared';
import { existsAsHtmlElement, getMockComponent, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { createCollaborationListResource } from 'libs/collaboration-shared/test/collaboration';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { MockComponent } from 'ng-mocks';
import { CollaborationInVorgangComponent } from './collaboration-in-vorgang.component';
import { ExterneFachstelleContainerComponent } from './externe-fachstelle-container/externe-fachstelle-container.component';
import { OrganisationsEinheitContainerComponent } from './organisations-einheit-container/organisations-einheit-container.component';

describe('CollaborationInVorgangComponent', () => {
  let component: CollaborationInVorgangComponent;
  let fixture: ComponentFixture<CollaborationInVorgangComponent>;

  const externeFachstelleContainer: string = getDataTestIdOf('externe-fachstelle-container');
  const organisationsEinheitContainer: string = getDataTestIdOf('organisations-einheit-container');

  const collaborationListResource: CollaborationListResource = createCollaborationListResource();
  const vorgang: VorgangWithEingangResource = createVorgangWithEingangResource();

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        CollaborationInVorgangComponent,
        HasLinkPipe,
        MockComponent(OrganisationsEinheitContainerComponent),
        MockComponent(ExterneFachstelleContainerComponent),
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(CollaborationInVorgangComponent);
    component = fixture.componentInstance;
    component.vorgang = vorgang;
    component.collaborationStateListResource = createStateResource(collaborationListResource);
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    describe('on createCollaborationRequest link', () => {
      describe('exists', () => {
        const collaborationListResourceWithLink: CollaborationListResource = createCollaborationListResource([
          CollaborationListLinkRel.CREATE_COLLABORATION_REQUEST,
        ]);

        beforeEach(() => {
          component.collaborationStateListResource = createStateResource(collaborationListResourceWithLink);
          fixture.detectChanges();
        });

        describe('and organisations einheit', () => {
          describe('is visible', () => {
            beforeEach(() => {
              component.showOrganisationsEinheitAnfrageButton = true;
              fixture.detectChanges();
            });

            it('should show component', () => {
              existsAsHtmlElement(fixture, organisationsEinheitContainer);
            });

            describe('component should be called with', () => {
              it('vorgang', () => {
                const comp: OrganisationsEinheitContainerComponent = getMockComponent<OrganisationsEinheitContainerComponent>(
                  fixture,
                  OrganisationsEinheitContainerComponent,
                );

                expect(comp.vorgang).toBe(vorgang);
              });
              it('collaborationListResource', () => {
                const comp: OrganisationsEinheitContainerComponent = getMockComponent<OrganisationsEinheitContainerComponent>(
                  fixture,
                  OrganisationsEinheitContainerComponent,
                );

                expect(comp.collaborationListResource).toBe(collaborationListResourceWithLink);
              });
            });
          });

          describe('is not visible', () => {
            beforeEach(() => {
              component.showOrganisationsEinheitAnfrageButton = false;
              fixture.detectChanges();
            });

            it('should hide component', () => {
              notExistsAsHtmlElement(fixture, organisationsEinheitContainer);
            });
          });
        });

        describe('and externe fachstelle', () => {
          describe('is visible', () => {
            beforeEach(() => {
              component.showExterneFachstelleAnfrageButton = true;
              fixture.detectChanges();
            });

            it('should show component', () => {
              existsAsHtmlElement(fixture, externeFachstelleContainer);
            });

            describe('component should be called with', () => {
              it('vorgang', () => {
                const comp: ExterneFachstelleContainerComponent = getMockComponent<ExterneFachstelleContainerComponent>(
                  fixture,
                  ExterneFachstelleContainerComponent,
                );

                expect(comp.vorgang).toBe(vorgang);
              });
              it('collaborationListResource', () => {
                const comp: ExterneFachstelleContainerComponent = getMockComponent<ExterneFachstelleContainerComponent>(
                  fixture,
                  ExterneFachstelleContainerComponent,
                );

                expect(comp.collaborationListResource).toBe(collaborationListResourceWithLink);
              });
            });
          });

          describe('is not visible', () => {
            beforeEach(() => {
              component.showExterneFachstelleAnfrageButton = false;
              fixture.detectChanges();
            });

            it('should hide component', () => {
              notExistsAsHtmlElement(fixture, externeFachstelleContainer);
            });
          });
        });
      });

      describe('not exists', () => {
        const collaborationListResource: CollaborationListResource = createCollaborationListResource();

        beforeEach(() => {
          component.collaborationStateListResource = createStateResource(collaborationListResource);
          fixture.detectChanges();
        });

        it('should hide externe fachstelle component', () => {
          fixture.detectChanges();

          notExistsAsHtmlElement(fixture, externeFachstelleContainer);
        });

        it('should hide organisations einheit component', () => {
          fixture.detectChanges();

          notExistsAsHtmlElement(fixture, externeFachstelleContainer);
        });
      });
    });
  });
});
