import {
  dispatchEventFromFixture,
  existsAsHtmlElement,
  getMockComponent,
  MockEvent,
  notExistsAsHtmlElement,
} from '@alfa-client/test-utils';
import { OrganisationsEinheitResource } from '@alfa-client/zustaendige-stelle-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { getUrl } from '@ngxp/rest';
import { CancelDialogButtonComponent } from '@ods/component';
import { MockComponent } from 'ng-mocks';
import { getDataTestIdOf } from '../../../../../tech-shared/test/data-test';
import { createOrganisationsEinheitResource } from '../../../../../zustaendige-stelle-shared/test/organisations-einheit';
import { ForwardingButtonComponent } from './forwarding-button/forwarding-button.component';
import { ForwardingDialogComponent } from './forwarding-dialog.component';
import { SelectedSearchItemComponent } from './selected-search-item/selected-search-item.component';
import { ForwardingSearchOrganisationsEinheitComponent } from './search-organisations-einheit/search-organisations-einheit.component';

describe('ForwardingDialogComponent', () => {
  let component: ForwardingDialogComponent;
  let fixture: ComponentFixture<ForwardingDialogComponent>;

  const organisationsEinheitSearch: string = getDataTestIdOf('organisations-einheit-search');
  const selectedSearchItem: string = getDataTestIdOf('selected-search-item');
  const forwardButton: string = getDataTestIdOf('foward-dialog-forward-button');

  const organisationsEinheitResource: OrganisationsEinheitResource = createOrganisationsEinheitResource();

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [ForwardingDialogComponent],
      declarations: [
        MockComponent(CancelDialogButtonComponent),
        MockComponent(ForwardingButtonComponent),
        MockComponent(SelectedSearchItemComponent),
        MockComponent(ForwardingSearchOrganisationsEinheitComponent),
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(ForwardingDialogComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    describe('zufi search', () => {
      it('should render if selectedSearchResult is null', () => {
        component.selectedSearchResult = null;

        fixture.detectChanges();

        existsAsHtmlElement(fixture, organisationsEinheitSearch);
      });

      it('should NOT render if selectedSearchResult is NOT null', () => {
        component.selectedSearchResult = organisationsEinheitResource;

        fixture.detectChanges();

        notExistsAsHtmlElement(fixture, organisationsEinheitSearch);
      });
    });
  });

  it('should render zufi search if selectedSearchResult is null', () => {
    component.selectedSearchResult = null;

    fixture.detectChanges();
  });

  describe('forwarding item', () => {
    it('should render if selectedSearchResult is NOT null', () => {
      component.selectedSearchResult = organisationsEinheitResource;

      fixture.detectChanges();

      existsAsHtmlElement(fixture, selectedSearchItem);
    });

    it('should NOT render if selectedSearchResult is null', () => {
      component.selectedSearchResult = null;

      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, selectedSearchItem);
    });
  });

  describe('forwarding button', () => {
    it('should be disabled if selectedSearchResult is null', () => {
      component.selectedSearchResult = null;

      fixture.detectChanges();

      const forwardingButton: ForwardingButtonComponent = getMockComponent(fixture, ForwardingButtonComponent);
      expect(forwardingButton.disabled).toBeTruthy();
    });

    it('should NOT be disabled if selectedSearchResult is NOT null', () => {
      component.selectedSearchResult = organisationsEinheitResource;

      fixture.detectChanges();

      const forwardingButton: ForwardingButtonComponent = getMockComponent(fixture, ForwardingButtonComponent);
      expect(forwardingButton.disabled).toBeFalsy();
    });
  });

  describe('forward button', () => {
    it('should emit on click', () => {
      component.selectedSearchResult = organisationsEinheitResource;
      component.forward.emit = jest.fn();

      dispatchEventFromFixture(fixture, forwardButton, MockEvent.CLICK);

      expect(component.forward.emit).toHaveBeenCalledWith(getUrl(organisationsEinheitResource));
    });
  });
});
