/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ON_PAGE, PostfachMailLinkRel } from '@alfa-client/postfach-shared';
import { FormatDateWithTimePipe, HasLinkPipe } from '@alfa-client/tech-shared';
import { getDebugElementFromFixtureByCss, getElementFromFixture } from '@alfa-client/test-utils';
import { registerLocaleData } from '@angular/common';
import localeDe from '@angular/common/locales/de';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MatIcon } from '@angular/material/icon';
import { provideRouter, RouterLinkWithHref, RouterModule } from '@angular/router';
import { getDataTestClassOf, getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { createPostfachMailResource } from '../../../../../../../postfach-shared/test/postfach';
import { PostfachMailDateComponent } from '../postfach-mail-date/postfach-mail-date.component';
import { IncommingMailComponent } from './incomming-mail.component';

registerLocaleData(localeDe);

describe('IncommingMailComponent', () => {
  let component: IncommingMailComponent;
  let fixture: ComponentFixture<IncommingMailComponent>;

  const attachmentIcon: string = getDataTestIdOf('postfach-nachricht-attachment-icon');
  const routing: string = getDataTestClassOf('incoming-mail-routing');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        IncommingMailComponent,
        MatIcon,
        FormatDateWithTimePipe,
        MockComponent(PostfachMailDateComponent),
        HasLinkPipe,
        MatIcon,
      ],
      imports: [RouterModule],
      providers: [
        provideRouter([]),
        {
          provide: ON_PAGE,
          useValue: undefined,
        },
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(IncommingMailComponent);
    component = fixture.componentInstance;
    component.postfachMail = createPostfachMailResource();
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('attachments', () => {
    it('should only show attachment icon on detail', () => {
      component.onPage = false;
      component.postfachMail = createPostfachMailResource([PostfachMailLinkRel.ATTACHMENTS]);
      fixture.detectChanges();

      const element = getElementFromFixture(fixture, attachmentIcon);

      expect(element).toBeInstanceOf(HTMLElement);
    });
  });

  describe('routing should be', () => {
    it('null on page site', () => {
      component.onPage = false;

      fixture.detectChanges();

      const routerElement = getDebugElementFromFixtureByCss(fixture, routing);
      const routerLinkInstance: RouterLinkWithHref = (<any>routerElement).injector.get(RouterLinkWithHref);
      expect((<any>routerLinkInstance).routerLinkInput[0]).toEqual('postfach');
    });

    it('"postfach" on detail site', () => {
      component.onPage = true;

      fixture.detectChanges();

      const routerElement = getDebugElementFromFixtureByCss(fixture, routing);
      const routerLinkInstance: RouterLinkWithHref = (<any>routerElement).injector.get(RouterLinkWithHref);
      expect((<any>routerLinkInstance).routerLinkInput).toBeNull();
    });
  });
});
