/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ResourceRedirectComponent } from '@alfa-client/resource-redirect';
import { ResourceRedirectService } from '@alfa-client/resource-redirect-shared';
import { Mock, mock } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ActivatedRoute } from '@angular/router';
import { Observable, of } from 'rxjs';

describe('ResourceRedirectComponent', () => {
  let component: ResourceRedirectComponent;
  let fixture: ComponentFixture<ResourceRedirectComponent>;
  let resourceRedirectService: Mock<ResourceRedirectService>;

  const initActivatedRoute = (queryParamKey?: string): { queryParamMap: Observable<Map<string, string>> } => ({
    queryParamMap: of(new Map(queryParamKey ? [[queryParamKey, 'some-uri']] : [])),
  });

  const createComponentWithQueryParam = (queryParamKey?: string): void => {
    TestBed.configureTestingModule({
      imports: [ResourceRedirectComponent],
      providers: [
        { provide: ActivatedRoute, useValue: initActivatedRoute(queryParamKey) },
        { provide: ResourceRedirectService, useValue: resourceRedirectService },
      ],
    });

    fixture = TestBed.createComponent(ResourceRedirectComponent);
    component = fixture.componentInstance;
  };

  beforeEach(() => {
    TestBed.resetTestingModule();

    resourceRedirectService = mock(ResourceRedirectService);
  });

  it('should create', () => {
    createComponentWithQueryParam();

    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    it('should call resource service redirectToResource', () => {
      createComponentWithQueryParam('uri');

      component.ngOnInit();

      expect(resourceRedirectService.redirectToResource).toHaveBeenCalledWith('some-uri');
    });

    it('should not call resource service redirectToResource with other query param', () => {
      createComponentWithQueryParam('some-other-param');

      component.ngOnInit();

      expect(resourceRedirectService.redirectToResource).not.toHaveBeenCalled();
    });

    it('should not call resource service redirectToResource without uri param', () => {
      createComponentWithQueryParam();

      component.ngOnInit();

      expect(resourceRedirectService.redirectToResource).not.toHaveBeenCalled();
    });
  });
});
