/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { HasLinkPipe } from '@alfa-client/tech-shared';
import { existsAsHtmlElement, mock, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { DialogService } from '@alfa-client/ui';
import { VorgangWithEingangLinkRel } from '@alfa-client/vorgang-shared';
import { AktenzeichenComponent } from '@alfa-client/vorgang-shared-ui';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ButtonComponent, EditIconComponent, TooltipDirective } from '@ods/system';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { MockComponent, MockDirective } from 'ng-mocks';
import { AktenzeichenEditDialogComponent } from '../aktenzeichen-edit-dialog/aktenzeichen-edit-dialog.component';
import { AktenzeichenEditableComponent } from './aktenzeichen-editable.component';

describe('AktenzeichenComponent', () => {
  let component: AktenzeichenEditableComponent;
  let fixture: ComponentFixture<AktenzeichenEditableComponent>;

  const editButton: string = getDataTestIdOf('aktenzeichen-editieren');

  const dialogService = mock(DialogService);

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        HasLinkPipe,
        AktenzeichenEditableComponent,
        MockComponent(ButtonComponent),
        MockComponent(EditIconComponent),
        MockComponent(AktenzeichenComponent),
        MockDirective(TooltipDirective),
      ],
      providers: [
        {
          provide: DialogService,
          useValue: dialogService,
        },
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(AktenzeichenEditableComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('onEdit', () => {
    it('should open dialog', () => {
      const vorgang = createVorgangWithEingangResource();
      component.vorgang = vorgang;

      component.onEdit();

      expect(dialogService.openWidely).toHaveBeenCalledWith(AktenzeichenEditDialogComponent, {
        data: { vorgang: vorgang },
      });
    });
  });

  describe('after render', () => {
    it('should NOT render edit button', () => {
      notExistsAsHtmlElement(fixture, editButton);
    });

    it('should render edit button', () => {
      const vorgang = createVorgangWithEingangResource();
      vorgang._links[VorgangWithEingangLinkRel.SET_AKTENZEICHEN] = { href: 'http' };
      component.vorgang = vorgang;

      fixture.detectChanges();

      existsAsHtmlElement(fixture, editButton);
    });
  });
});
