/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { faker } from '@faker-js/faker';
import { times } from 'lodash-es';
import { toResource } from '../../tech-shared/test/resource';
import { OrganisationsEinheitListLinkRel } from '../src/lib/organisations-einheit/organisations-einheit.linkrel';
import {
  Anschrift,
  OrganisationsEinheit,
  OrganisationsEinheitListResource,
  OrganisationsEinheitResource,
} from '../src/lib/organisations-einheit/organisations-einheit.model';

export function createAnschrift(): Anschrift {
  return {
    hausnummer: faker.word.sample(),
    ort: faker.word.sample(),
    plz: faker.word.sample(),
    strasse: faker.word.sample(2),
  };
}

export function createOrganisationsEinheit(): OrganisationsEinheit {
  return {
    name: faker.word.sample(),
    anschrift: createAnschrift(),
    organisationEinheitId: faker.string.uuid(),
  };
}

export function createOrganisationsEinheitResource(linkRel: string[] = []): OrganisationsEinheitResource {
  return toResource(createOrganisationsEinheit(), linkRel);
}

export function createOrganisationsEinheitResources(linkRelations: string[] = []): OrganisationsEinheitResource[] {
  return times(10, () => toResource(createOrganisationsEinheitResource(), [...linkRelations]));
}

export function createOrganisationsEinheitListResource(
  resources?: OrganisationsEinheitResource[],
  linkRelations: string[] = [],
): OrganisationsEinheitListResource {
  return toResource({}, [...linkRelations], {
    [OrganisationsEinheitListLinkRel.ORGANISATIONS_EINHEIT_HEADER_LIST]:
      resources ? resources : createOrganisationsEinheitResources(),
  });
}
