/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { getElementFromFixture } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { ZustaendigeStelleHeaderComponent } from './zustaendige-stelle-header.component';

describe('ZustaendigeStelleHeaderComponent', () => {
  let component: ZustaendigeStelleHeaderComponent;
  let fixture: ComponentFixture<ZustaendigeStelleHeaderComponent>;
  const titleSelector = getDataTestIdOf('zustaendige-stelle-header-title');
  const subTitleSelector = getDataTestIdOf('zustaendige-stelle-header-sub-title');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [ZustaendigeStelleHeaderComponent],
    }).compileComponents();

    fixture = TestBed.createComponent(ZustaendigeStelleHeaderComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    describe('title', () => {
      it('should show title', () => {
        component.title = 'I am test title';
        fixture.detectChanges();

        const titleElement: HTMLElement = getElementFromFixture(fixture, titleSelector);

        expect(titleElement.innerHTML).toContain('I am test title');
      });
    });

    describe('subTitle', () => {
      it('should show sub title', () => {
        component.subTitle = 'I am test sub title';
        fixture.detectChanges();

        const subTitleElement: HTMLElement = getElementFromFixture(fixture, subTitleSelector);

        expect(subTitleElement.innerHTML).toContain('I am test sub title');
      });
    });

    describe('isSubTitleBold', () => {
      it('should add class if true', () => {
        component.subTitle = 'I am test sub title';
        component.isSubTitleBold = true;
        fixture.detectChanges();

        const subTitleElement: HTMLElement = getElementFromFixture(fixture, subTitleSelector);

        expect(subTitleElement.classList).toContain('font-medium');
      });

      it('should not add class if false', () => {
        component.subTitle = 'I am test sub title';
        component.isSubTitleBold = false;
        fixture.detectChanges();

        const subTitleElement: HTMLElement = getElementFromFixture(fixture, subTitleSelector);

        expect(subTitleElement.classList).not.toContain('font-medium');
      });
    });
  });
});
